@@ -8,14 +8,13 @@ This program can be distributed under the terms of the GNU GPLv3.
 
 from __future__ import division, print_function, absolute_import
 from ..common import QuietError, BUFSIZE
-from .common import (AbstractBackend, NoSuchObject, retry, AuthorizationError, http_connection,
-                     DanglingStorageURL)
-from .s3c import HTTPError, BadDigest
+from .common import (AbstractBackend, NoSuchObject, retry, AuthorizationError, http_connection, 
+    DanglingStorageURLError)
+from .s3c import HTTPError, BadDigestError
+from s3ql.backends.common import is_temp_network_error
 from urlparse import urlsplit
-import json
-import errno
 import hashlib
-import httplib
+import json
 import logging
 import re
 import tempfile
@@ -59,7 +58,7 @@ class Backend(AbstractBackend):
             resp = self._do_request('GET', '/', query_string={'limit': 1 })
         except HTTPError as exc:
             if exc.status == 404:
-                raise DanglingStorageURL(self.container_name)
+                raise DanglingStorageURLError(self.container_name)
             raise
         resp.read()   
                     
@@ -98,23 +97,13 @@ class Backend(AbstractBackend):
         problems and so that the request can be manually restarted if applicable.
         '''
 
-        if isinstance(exc, (httplib.IncompleteRead,)):
+        if isinstance(exc, (AuthenticationExpired,)):
             return True
 
-        # Server closed connection
-        elif (isinstance(exc, httplib.BadStatusLine)
-              and (not exc.line or exc.line == "''")):
-            return True
-
-        elif (isinstance(exc, IOError) and
-              exc.errno in (errno.EPIPE, errno.ECONNRESET, errno.ETIMEDOUT,
-                            errno.EINTR)):
-            return True
-        
         elif isinstance(exc, HTTPError) and exc.status >= 500 and exc.status <= 599:
             return True
 
-        elif isinstance(exc, AuthenticationExpired):
+        elif is_temp_network_error(exc):
             return True
                 
         return False
@@ -415,7 +404,7 @@ class Backend(AbstractBackend):
                                                                   'limit': batch_size })
             except HTTPError as exc:
                 if exc.status == 404:
-                    raise DanglingStorageURL(self.container_name)
+                    raise DanglingStorageURLError(self.container_name)
                 raise
             
             if resp.status == 204:
@@ -498,7 +487,7 @@ class ObjectW(object):
             except:
                 log.exception('Objectw(%s).close(): unable to delete corrupted object!',
                               self.key)            
-            raise BadDigest('BadDigest', 'Received ETag does not agree with our calculations.')
+            raise BadDigestError('BadDigest', 'Received ETag does not agree with our calculations.')
 
     def __enter__(self):
         return self
@@ -562,7 +551,7 @@ class ObjectR(object):
             if etag != self.md5.hexdigest():
                 log.warn('ObjectR(%s).close(): MD5 mismatch: %s vs %s', self.key, etag,
                          self.md5.hexdigest())
-                raise BadDigest('BadDigest', 'ETag header does not agree with calculated MD5')
+                raise BadDigestError('BadDigest', 'ETag header does not agree with calculated MD5')
             return buf
 
         self.md5.update(buf)
@@ -603,4 +592,4 @@ class AuthenticationExpired(Exception):
     def __str__(self):
         return 'Auth token expired. Server said: %s' % self.msg
     
-        
\ No newline at end of file
+        
