@@ -8,7 +8,6 @@ This program can be distributed under the terms of the GNU GPLv3.
 
 from __future__ import division, print_function, absolute_import
 
-from _common import TestCase
 import unittest2 as unittest
 from s3ql import deltadump
 import tempfile
@@ -16,7 +15,7 @@ from s3ql.database import Connection
 import random
 import time
 
-class DumpTests(TestCase):
+class DumpTests(unittest.TestCase):
     def setUp(self):
         self.src = Connection(":memory:")
         self.dst = Connection(":memory:")
@@ -185,7 +184,6 @@ class DumpTests(TestCase):
         vals += [ -v for v  in vals ]
         vals.append(-(2 ** 63))
 
-        vals = range(5)
         for val in vals:
             db.execute('INSERT INTO test (id) VALUES(?)', (val,))
 
